@@ -36,7 +36,7 @@
 #include <KStandardGuiItem>
 #include <KTitleWidget>
 
-#include <KActivities/ResourceInstance>
+#include <PlasmaActivities/ResourceInstance>
 
 #include <cmath>
 #include <kpluginmetadata.h>
@@ -272,6 +272,12 @@ void ModuleView::addModule(MenuItem *item, const QStringList &args)
         kcm->widget()->setAutoFillBackground(false);
         kcm->load();
         connect(kcm, &KCModule::needsSaveChanged, this, &ModuleView::stateChanged);
+        connect(kcm, &KCModule::representsDefaultsChanged, this, [this, kcm]() {
+            if (kcm == d->mPages.value(d->mPageWidget->currentPage()) && kcm->buttons() & d->mButtonMask & KCModule::Default) {
+                d->mDefault->setEnabled(!kcm->representsDefaults());
+            }
+        });
+
         d->mPages.insert(page, kcm);
     }
 
