@@ -8,14 +8,15 @@
 #ifndef MODULE_VIEW_H
 #define MODULE_VIEW_H
 
+#include <KAuth/Action>
 #include <KPageView>
+
 #include <QModelIndex>
 #include <QWidget>
 
 #include "systemsettingsview_export.h"
 
-class KCModuleInfo;
-class KCModuleProxy;
+class KCModule;
 class KPageWidgetItem;
 class KPluginMetaData;
 class MenuItem;
@@ -124,7 +125,9 @@ public:
     qreal headerHeight() const;
     void setHeaderHeight(qreal height);
 
-    void setActiveModule(const QString &moduleName);
+    void setActiveModule(const QString &pluginId);
+
+    void requestActivation(const QVariantList &args);
 
     /**
      * The active module's KPluginMetaData.
@@ -166,15 +169,16 @@ public Q_SLOTS:
     void keyPressEvent(QKeyEvent *event) override;
 
 private:
-    bool resolveChanges(KCModuleProxy *currentProxy);
+    bool resolveChanges(KCModule *currentProxy);
     void addModule(MenuItem *item, const QStringList &args);
-    bool moduleSave(KCModuleProxy *module);
+    bool moduleSave(KCModule *module);
     void updatePageIconHeader(KPageWidgetItem *page);
     void updateButtons();
 
 private Q_SLOTS:
     void activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *previous);
     void stateChanged();
+    void authStatusChanged(KAuth::Action::AuthStatus status);
 
 Q_SIGNALS:
     /**
